@@ -1,7 +1,7 @@
 package Class::GenSource;
 
 our $DATE = '2015-06-10'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -70,7 +70,7 @@ sub gen_class_source_code {
         if ($variant =~ /^Mo/) {
             push @res, "has $name => (is=>'rw');\n";
         } else {
-            push @res, "sub $name {}\n";
+            push @res, "sub $name { \$_[0]{'$name'} }\n";
         }
     }
 
@@ -92,7 +92,7 @@ Class::GenSource - Generate Perl source code to declare a class
 
 =head1 VERSION
 
-This document describes version 0.02 of Class::GenSource (from Perl distribution Class-GenSource), released on 2015-06-10.
+This document describes version 0.03 of Class::GenSource (from Perl distribution Class-GenSource), released on 2015-06-10.
 
 =head1 SYNOPSIS
 
@@ -112,9 +112,9 @@ Will print something like:
  package My::Class;
 
  sub new { my $class = shift; bless {@_}, $class }
- sub foo {}
- sub bar {}
- sub baz {}
+ sub foo { $_[0]{foo} }
+ sub bar { $_[0]{bar} }
+ sub baz { $_[0]{baz} }
 
 Another example (generating L<Moo>-based class):
 
